<?php
namespace FM\Service;

use FM\Factory\SetoresFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;

class SetoresService {
    
    protected $SetoresFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;
    
    public function __construct (SetoresFactory $SetoresFactory, Environment $Environment, NewCode $newCode, EntityManager $entityManager) {
        $this->SetoresFactory               = $SetoresFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getSectorsService() {

        return $this->SetoresFactory->getSectorsFactory();
    }
    
    public function sectorsListService(){
        $operadores = $this->SetoresFactory->sectorsListFactory();
        return $operadores;
    }
    
     public function createSectorService($nmsetor, $nrfuncresponsavel) {
        $this->connection->beginTransaction();

        try {
            $nrsetor = $this->newCode->getCodeByTableName('FCM_SETOR',  $this->Environment->getNrOrg(), 1, 10, true);
        
            $sectorInfos = array(
                'NRSETOR'           => $nrsetor,
                'NMSETOR'           => $nmsetor,
                'NRFUNCRESPONSAVEL' => $nrfuncresponsavel,
                'IDATIVO'           => 'S'
            );

            $this->SetoresFactory->createSectorFactory($sectorInfos);
            $this->connection->commit();

        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function getSectorInfosService($nrsetor){
        $params = array (
          'NRSETOR' => $nrsetor   
        );
        
        $operadores = $this->SetoresFactory->getSectorInfosFactory($params);
        return $operadores;
    }
    
    public function updateSectorService($nrsetor, $nmsetor, $nrfuncresponsavel) {
        $this->connection->beginTransaction();

        try {
            $params = array(
                'NRSETOR' => $nrsetor,
                'NMSETOR' => $nmsetor,
                'NRFUNCRESPONSAVEL' => $nrfuncresponsavel,
            );

            $this->SetoresFactory->updateSectorFactory($params);
            $this->connection->commit();

        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deleteSectorsService($params) {
        $cont = 0;
        $this->connection->beginTransaction();
    
        try {

            foreach ($params['NRSETOR'] as $nr ) {
                $validParam = array (
                    'NRSETOR' => $nr
                );

                $validaLocal = $this->SetoresFactory->validSectorsInLocalFactory($validParam);
                $valida = $validaLocal[0]['VALIDA'];

                if ($valida == 0) {
                    $validaCheckList = $this->SetoresFactory->validSectorsInChecklistFactory($validParam);
                    $valida = $validaCheckList[0]['VALIDA'];
                    
                    if ($valida == 0) {
                        $validaRelacFunc = $this->SetoresFactory->validSectorsInRelacFuncFactory($validParam);
                        $valida = $validaRelacFunc[0]['VALIDA'];
                        
                        if ($valida == 0) {
                          $this->SetoresFactory->deleteSectorsFactory($validParam);
                        } else {
                            $cont = $cont + 1;
                        }
                        
                    } else {
                        $cont = $cont + 1;
                    }
                } else {
                    $cont = $cont + 1; 
                } 
            }

            $this->connection->commit();
            return $cont;

        } catch(\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function getLinkedLocalsService($params){

        $operadores = $this->SetoresFactory->getLinkedLocalsFactory($params);
        return $operadores;
    }
}
?>